==> 0.1.90.tar.gz: lib/widgets/default_profile_img.dart <==
import 'dart:math';
import 'package:feed_plugin/utilities/colors.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

class DefaultProfileImg extends StatefulWidget {
  const DefaultProfileImg({
    Key key,
    this.firstName,
    this.lastName,
    this.heightProfileImage,
    this.widthProfileImage,
  }) : super(key: key);

  final String firstName;
  final String lastName;
  final int heightProfileImage;
  final int widthProfileImage;

  @override
  _DefaultProfileImgState createState() => _DefaultProfileImgState();
}

class _DefaultProfileImgState extends State<DefaultProfileImg> {
  bool flagLast;
  bool flagFirst;

  @override
  void initState() {
    check();
    super.initState();
  }

  check() {
    bool flag1 = true;
    bool flag2 = true;

    if (widget.lastName == null ||
        widget.lastName == "null" ||
        widget.lastName == "") {
      flag1 = false;
    }
    if (widget.firstName == null ||
        widget.firstName == "null" ||
        widget.firstName == "") {
      flag2 = false;
    }

    setState(() {
      flagFirst = flag2;
      flagLast = flag1;
    });
  }

  @override
  Widget build(BuildContext context) {
    return ClipOval(
      child: Material(
        color: Color(0xffE8ECEF),
        child: SizedBox(
          width: this.widget.widthProfileImage.toDouble(),
          //ScreenUtil().setWidth(38),
          height: this.widget.heightProfileImage.toDouble(),
          //ScreenUtil().setWidth(39),
          child: Center(
            child: Text(
              flagFirst && flagLast
                  ? this.widget.firstName.trimLeft().substring(0, 1) +
                      this.widget.lastName.trimLeft().substring(0, 1)
                  : flagFirst && !flagLast
                      ? this.widget.firstName.trimLeft().substring(0, 1)
                      : !flagFirst && flagLast
                          ? this.widget.lastName.trimLeft().substring(0, 1)
                          : "",
              style: TextStyle(
                color: primaryColor,
                fontSize: ScreenUtil().setSp(15),
              ),
            ),
          ),
        ),
      ),
    );
  }
}

==> 0.2.11.tar.gz: lib/widgets/default_profile_img.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

class DefaultProfileImg extends StatefulWidget {
  const DefaultProfileImg({
    Key key,
    this.firstName,
    this.lastName,
  }) : super(key: key);

  final String firstName;
  final String lastName;

  @override
  _DefaultProfileImgState createState() => _DefaultProfileImgState();
}

class _DefaultProfileImgState extends State<DefaultProfileImg> {
  bool flagLast;
  bool flagFirst;

  @override
  void initState() {
    check();
    super.initState();
  }

  check() {
    bool flag1 = true;
    bool flag2 = true;

    if (widget.lastName == null ||
        widget.lastName == "null" ||
        widget.lastName == "") {
      flag1 = false;
    }
    if (widget.firstName == null ||
        widget.firstName == "null" ||
        widget.firstName == "") {
      flag2 = false;
    }

    setState(() {
      flagFirst = flag2;
      flagLast = flag1;
    });
  }

  @override
  Widget build(BuildContext context) {
    return ClipOval(
      child: Material(
        color: Color(0xffE8ECEF),
        child: SizedBox(
          width: ScreenUtil().setWidth(38),
          height: ScreenUtil().setWidth(39),
          child: Center(
            child: Text(
              flagFirst && flagLast
                  ? this.widget.firstName.trim().substring(0, 1) +
                      this.widget.lastName.trim().substring(0, 1)
                  :flagFirst && !flagLast ? this.widget.firstName.trim().substring(0, 1)
                  :!flagFirst && flagLast ? this.widget.lastName.trim().substring(0, 1):
                  "",
              style: TextStyle(
                color: Color(0xFF083356),
                fontSize: ScreenUtil().setSp(15),
              ),
            ),
          ),
        ),
      ),
    );
  }
}
